# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'DeploymentExpenseArgs',
    'DeploymentLastRequestArgs',
    'DeploymentProjectArgs',
    'DeploymentResourceArgs',
    'DeploymentResourceExpenseArgs',
]

@pulumi.input_type
class DeploymentExpenseArgs:
    def __init__(__self__, *,
                 additional_expense: Optional[pulumi.Input[float]] = None,
                 code: Optional[pulumi.Input[str]] = None,
                 compute_expense: Optional[pulumi.Input[float]] = None,
                 last_update_time: Optional[pulumi.Input[str]] = None,
                 message: Optional[pulumi.Input[str]] = None,
                 network_expense: Optional[pulumi.Input[float]] = None,
                 storage_expense: Optional[pulumi.Input[float]] = None,
                 total_expense: Optional[pulumi.Input[float]] = None,
                 unit: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[float] additional_expense: Additional expense incurred for the resource.
        :param pulumi.Input[str] code: Expense sync message code if any.
        :param pulumi.Input[float] compute_expense: Compute expense of the entity.
        :param pulumi.Input[str] last_update_time: Last expense sync time.
        :param pulumi.Input[str] message: Expense sync message if any.
        :param pulumi.Input[float] network_expense: Network expense of the entity.
        :param pulumi.Input[float] storage_expense: Storage expense of the entity.
        :param pulumi.Input[float] total_expense: Total expense of the entity.
        :param pulumi.Input[str] unit: Monetary unit.
        """
        if additional_expense is not None:
            pulumi.set(__self__, "additional_expense", additional_expense)
        if code is not None:
            pulumi.set(__self__, "code", code)
        if compute_expense is not None:
            pulumi.set(__self__, "compute_expense", compute_expense)
        if last_update_time is not None:
            pulumi.set(__self__, "last_update_time", last_update_time)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if network_expense is not None:
            pulumi.set(__self__, "network_expense", network_expense)
        if storage_expense is not None:
            pulumi.set(__self__, "storage_expense", storage_expense)
        if total_expense is not None:
            pulumi.set(__self__, "total_expense", total_expense)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter(name="additionalExpense")
    def additional_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Additional expense incurred for the resource.
        """
        return pulumi.get(self, "additional_expense")

    @additional_expense.setter
    def additional_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "additional_expense", value)

    @property
    @pulumi.getter
    def code(self) -> Optional[pulumi.Input[str]]:
        """
        Expense sync message code if any.
        """
        return pulumi.get(self, "code")

    @code.setter
    def code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "code", value)

    @property
    @pulumi.getter(name="computeExpense")
    def compute_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Compute expense of the entity.
        """
        return pulumi.get(self, "compute_expense")

    @compute_expense.setter
    def compute_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "compute_expense", value)

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> Optional[pulumi.Input[str]]:
        """
        Last expense sync time.
        """
        return pulumi.get(self, "last_update_time")

    @last_update_time.setter
    def last_update_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_update_time", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Expense sync message if any.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="networkExpense")
    def network_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Network expense of the entity.
        """
        return pulumi.get(self, "network_expense")

    @network_expense.setter
    def network_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "network_expense", value)

    @property
    @pulumi.getter(name="storageExpense")
    def storage_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Storage expense of the entity.
        """
        return pulumi.get(self, "storage_expense")

    @storage_expense.setter
    def storage_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "storage_expense", value)

    @property
    @pulumi.getter(name="totalExpense")
    def total_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Total expense of the entity.
        """
        return pulumi.get(self, "total_expense")

    @total_expense.setter
    def total_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "total_expense", value)

    @property
    @pulumi.getter
    def unit(self) -> Optional[pulumi.Input[str]]:
        """
        Monetary unit.
        """
        return pulumi.get(self, "unit")

    @unit.setter
    def unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "unit", value)


@pulumi.input_type
class DeploymentLastRequestArgs:
    def __init__(__self__, *,
                 action_id: Optional[pulumi.Input[str]] = None,
                 approved_at: Optional[pulumi.Input[str]] = None,
                 blueprint_id: Optional[pulumi.Input[str]] = None,
                 cancelable: Optional[pulumi.Input[bool]] = None,
                 catalog_item_id: Optional[pulumi.Input[str]] = None,
                 completed_at: Optional[pulumi.Input[str]] = None,
                 completed_tasks: Optional[pulumi.Input[int]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 details: Optional[pulumi.Input[str]] = None,
                 dismissed: Optional[pulumi.Input[bool]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 initialized_at: Optional[pulumi.Input[str]] = None,
                 inputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 outputs: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 requested_by: Optional[pulumi.Input[str]] = None,
                 resource_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 total_tasks: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] action_id: Identifier of the requested action.
        :param pulumi.Input[str] approved_at: Time at which the request was approved.
        :param pulumi.Input[str] blueprint_id: Identifier of the requested blueprint in the form ‘UUID:version’.
        :param pulumi.Input[bool] cancelable: Indicates whether request can be canceled or not.
        :param pulumi.Input[str] catalog_item_id: The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        :param pulumi.Input[str] completed_at: Time at which the request completed.
        :param pulumi.Input[int] completed_tasks: The number of tasks completed while fulfilling this request.
        :param pulumi.Input[str] created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param pulumi.Input[str] details: Longer user-friendly details of the request.
        :param pulumi.Input[bool] dismissed: Indicates whether request is in dismissed state.
        :param pulumi.Input[str] id: Unique identifier of the resource.
        :param pulumi.Input[str] initialized_at: Time at which the request was initialized.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] inputs: Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] outputs: Request outputs.
        :param pulumi.Input[str] requested_by: The user that initiated the request.
        :param pulumi.Input[str] status: Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        :param pulumi.Input[str] updated_at: Last update time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        if action_id is not None:
            pulumi.set(__self__, "action_id", action_id)
        if approved_at is not None:
            pulumi.set(__self__, "approved_at", approved_at)
        if blueprint_id is not None:
            pulumi.set(__self__, "blueprint_id", blueprint_id)
        if cancelable is not None:
            pulumi.set(__self__, "cancelable", cancelable)
        if catalog_item_id is not None:
            pulumi.set(__self__, "catalog_item_id", catalog_item_id)
        if completed_at is not None:
            pulumi.set(__self__, "completed_at", completed_at)
        if completed_tasks is not None:
            pulumi.set(__self__, "completed_tasks", completed_tasks)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if dismissed is not None:
            pulumi.set(__self__, "dismissed", dismissed)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if initialized_at is not None:
            pulumi.set(__self__, "initialized_at", initialized_at)
        if inputs is not None:
            pulumi.set(__self__, "inputs", inputs)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if outputs is not None:
            pulumi.set(__self__, "outputs", outputs)
        if requested_by is not None:
            pulumi.set(__self__, "requested_by", requested_by)
        if resource_ids is not None:
            pulumi.set(__self__, "resource_ids", resource_ids)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if total_tasks is not None:
            pulumi.set(__self__, "total_tasks", total_tasks)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="actionId")
    def action_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of the requested action.
        """
        return pulumi.get(self, "action_id")

    @action_id.setter
    def action_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "action_id", value)

    @property
    @pulumi.getter(name="approvedAt")
    def approved_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time at which the request was approved.
        """
        return pulumi.get(self, "approved_at")

    @approved_at.setter
    def approved_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "approved_at", value)

    @property
    @pulumi.getter(name="blueprintId")
    def blueprint_id(self) -> Optional[pulumi.Input[str]]:
        """
        Identifier of the requested blueprint in the form ‘UUID:version’.
        """
        return pulumi.get(self, "blueprint_id")

    @blueprint_id.setter
    def blueprint_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "blueprint_id", value)

    @property
    @pulumi.getter
    def cancelable(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether request can be canceled or not.
        """
        return pulumi.get(self, "cancelable")

    @cancelable.setter
    def cancelable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "cancelable", value)

    @property
    @pulumi.getter(name="catalogItemId")
    def catalog_item_id(self) -> Optional[pulumi.Input[str]]:
        """
        The id of the vRA catalog item to request the deployment. Conflicts with `blueprint_id` and `blueprint_content`.
        """
        return pulumi.get(self, "catalog_item_id")

    @catalog_item_id.setter
    def catalog_item_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "catalog_item_id", value)

    @property
    @pulumi.getter(name="completedAt")
    def completed_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time at which the request completed.
        """
        return pulumi.get(self, "completed_at")

    @completed_at.setter
    def completed_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "completed_at", value)

    @property
    @pulumi.getter(name="completedTasks")
    def completed_tasks(self) -> Optional[pulumi.Input[int]]:
        """
        The number of tasks completed while fulfilling this request.
        """
        return pulumi.get(self, "completed_tasks")

    @completed_tasks.setter
    def completed_tasks(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "completed_tasks", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def details(self) -> Optional[pulumi.Input[str]]:
        """
        Longer user-friendly details of the request.
        """
        return pulumi.get(self, "details")

    @details.setter
    def details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "details", value)

    @property
    @pulumi.getter
    def dismissed(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether request is in dismissed state.
        """
        return pulumi.get(self, "dismissed")

    @dismissed.setter
    def dismissed(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "dismissed", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="initializedAt")
    def initialized_at(self) -> Optional[pulumi.Input[str]]:
        """
        Time at which the request was initialized.
        """
        return pulumi.get(self, "initialized_at")

    @initialized_at.setter
    def initialized_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "initialized_at", value)

    @property
    @pulumi.getter
    def inputs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Inputs provided by the user. For inputs including those with default values, refer to `inputs_including_defaults`.
        """
        return pulumi.get(self, "inputs")

    @inputs.setter
    def inputs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "inputs", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def outputs(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        Request outputs.
        """
        return pulumi.get(self, "outputs")

    @outputs.setter
    def outputs(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "outputs", value)

    @property
    @pulumi.getter(name="requestedBy")
    def requested_by(self) -> Optional[pulumi.Input[str]]:
        """
        The user that initiated the request.
        """
        return pulumi.get(self, "requested_by")

    @requested_by.setter
    def requested_by(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "requested_by", value)

    @property
    @pulumi.getter(name="resourceIds")
    def resource_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        return pulumi.get(self, "resource_ids")

    @resource_ids.setter
    def resource_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "resource_ids", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Deployment status. Supported values are: `CREATE_SUCCESSFUL`, `CREATE_INPROGRESS`, `CREATE_FAILED`, `UPDATE_SUCCESSFUL`, `UPDATE_INPROGRESS`, `UPDATE_FAILED`, `DELETE_SUCCESSFUL`, `DELETE_INPROGRESS`, `DELETE_FAILED`, `ACTION_SUCCESSFUL`, `ACTION_INPROGRESS`, `ACTION_FAILED`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="totalTasks")
    def total_tasks(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "total_tasks")

    @total_tasks.setter
    def total_tasks(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "total_tasks", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Last update time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.input_type
class DeploymentProjectArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] id: Unique identifier of the resource.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] version: Version of the entity, if applicable.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        Version of the entity, if applicable.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


@pulumi.input_type
class DeploymentResourceArgs:
    def __init__(__self__, *,
                 id: pulumi.Input[str],
                 name: pulumi.Input[str],
                 created_at: Optional[pulumi.Input[str]] = None,
                 depends_ons: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 expenses: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentResourceExpenseArgs']]]] = None,
                 properties_json: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 sync_status: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] id: Unique identifier of the resource.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[str] created_at: Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] depends_ons: A list of other resources this resource depends on.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['DeploymentResourceExpenseArgs']]] expenses: Expense incurred for the deployment.
        :param pulumi.Input[str] properties_json: List of properties in the encoded JSON string format.
        :param pulumi.Input[str] state: The current state of the resource. Supported values are `PARTIAL`, `TAINTED`, `OK.`
        :param pulumi.Input[str] sync_status: The current sync status. Supported values are `SUCCESS`, `MISSING`, `STALE`.
        :param pulumi.Input[str] type: Type of the resource.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "name", name)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if depends_ons is not None:
            pulumi.set(__self__, "depends_ons", depends_ons)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if expenses is not None:
            pulumi.set(__self__, "expenses", expenses)
        if properties_json is not None:
            pulumi.set(__self__, "properties_json", properties_json)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if sync_status is not None:
            pulumi.set(__self__, "sync_status", sync_status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> pulumi.Input[str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: pulumi.Input[str]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time (e.g. date format ‘2019-07-13T23:16:49.310Z’).
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="dependsOns")
    def depends_ons(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of other resources this resource depends on.
        """
        return pulumi.get(self, "depends_ons")

    @depends_ons.setter
    def depends_ons(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "depends_ons", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def expenses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentResourceExpenseArgs']]]]:
        """
        Expense incurred for the deployment.
        """
        return pulumi.get(self, "expenses")

    @expenses.setter
    def expenses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DeploymentResourceExpenseArgs']]]]):
        pulumi.set(self, "expenses", value)

    @property
    @pulumi.getter(name="propertiesJson")
    def properties_json(self) -> Optional[pulumi.Input[str]]:
        """
        List of properties in the encoded JSON string format.
        """
        return pulumi.get(self, "properties_json")

    @properties_json.setter
    def properties_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "properties_json", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the resource. Supported values are `PARTIAL`, `TAINTED`, `OK.`
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="syncStatus")
    def sync_status(self) -> Optional[pulumi.Input[str]]:
        """
        The current sync status. Supported values are `SUCCESS`, `MISSING`, `STALE`.
        """
        return pulumi.get(self, "sync_status")

    @sync_status.setter
    def sync_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sync_status", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[str]]:
        """
        Type of the resource.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "type", value)


@pulumi.input_type
class DeploymentResourceExpenseArgs:
    def __init__(__self__, *,
                 additional_expense: Optional[pulumi.Input[float]] = None,
                 code: Optional[pulumi.Input[str]] = None,
                 compute_expense: Optional[pulumi.Input[float]] = None,
                 last_update_time: Optional[pulumi.Input[str]] = None,
                 message: Optional[pulumi.Input[str]] = None,
                 network_expense: Optional[pulumi.Input[float]] = None,
                 storage_expense: Optional[pulumi.Input[float]] = None,
                 total_expense: Optional[pulumi.Input[float]] = None,
                 unit: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[float] additional_expense: Additional expense incurred for the resource.
        :param pulumi.Input[str] code: Expense sync message code if any.
        :param pulumi.Input[float] compute_expense: Compute expense of the entity.
        :param pulumi.Input[str] last_update_time: Last expense sync time.
        :param pulumi.Input[str] message: Expense sync message if any.
        :param pulumi.Input[float] network_expense: Network expense of the entity.
        :param pulumi.Input[float] storage_expense: Storage expense of the entity.
        :param pulumi.Input[float] total_expense: Total expense of the entity.
        :param pulumi.Input[str] unit: Monetary unit.
        """
        if additional_expense is not None:
            pulumi.set(__self__, "additional_expense", additional_expense)
        if code is not None:
            pulumi.set(__self__, "code", code)
        if compute_expense is not None:
            pulumi.set(__self__, "compute_expense", compute_expense)
        if last_update_time is not None:
            pulumi.set(__self__, "last_update_time", last_update_time)
        if message is not None:
            pulumi.set(__self__, "message", message)
        if network_expense is not None:
            pulumi.set(__self__, "network_expense", network_expense)
        if storage_expense is not None:
            pulumi.set(__self__, "storage_expense", storage_expense)
        if total_expense is not None:
            pulumi.set(__self__, "total_expense", total_expense)
        if unit is not None:
            pulumi.set(__self__, "unit", unit)

    @property
    @pulumi.getter(name="additionalExpense")
    def additional_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Additional expense incurred for the resource.
        """
        return pulumi.get(self, "additional_expense")

    @additional_expense.setter
    def additional_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "additional_expense", value)

    @property
    @pulumi.getter
    def code(self) -> Optional[pulumi.Input[str]]:
        """
        Expense sync message code if any.
        """
        return pulumi.get(self, "code")

    @code.setter
    def code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "code", value)

    @property
    @pulumi.getter(name="computeExpense")
    def compute_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Compute expense of the entity.
        """
        return pulumi.get(self, "compute_expense")

    @compute_expense.setter
    def compute_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "compute_expense", value)

    @property
    @pulumi.getter(name="lastUpdateTime")
    def last_update_time(self) -> Optional[pulumi.Input[str]]:
        """
        Last expense sync time.
        """
        return pulumi.get(self, "last_update_time")

    @last_update_time.setter
    def last_update_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_update_time", value)

    @property
    @pulumi.getter
    def message(self) -> Optional[pulumi.Input[str]]:
        """
        Expense sync message if any.
        """
        return pulumi.get(self, "message")

    @message.setter
    def message(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "message", value)

    @property
    @pulumi.getter(name="networkExpense")
    def network_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Network expense of the entity.
        """
        return pulumi.get(self, "network_expense")

    @network_expense.setter
    def network_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "network_expense", value)

    @property
    @pulumi.getter(name="storageExpense")
    def storage_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Storage expense of the entity.
        """
        return pulumi.get(self, "storage_expense")

    @storage_expense.setter
    def storage_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "storage_expense", value)

    @property
    @pulumi.getter(name="totalExpense")
    def total_expense(self) -> Optional[pulumi.Input[float]]:
        """
        Total expense of the entity.
        """
        return pulumi.get(self, "total_expense")

    @total_expense.setter
    def total_expense(self, value: Optional[pulumi.Input[float]]):
        pulumi.set(self, "total_expense", value)

    @property
    @pulumi.getter
    def unit(self) -> Optional[pulumi.Input[str]]:
        """
        Monetary unit.
        """
        return pulumi.get(self, "unit")

    @unit.setter
    def unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "unit", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectArgs', 'Project']

@pulumi.input_type
class ProjectArgs:
    def __init__(__self__, *,
                 administrator_roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]]] = None,
                 administrators: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 constraints: Optional[pulumi.Input['ProjectConstraintsArgs']] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 machine_naming_template: Optional[pulumi.Input[str]] = None,
                 member_roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operation_timeout: Optional[pulumi.Input[int]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 shared_resources: Optional[pulumi.Input[bool]] = None,
                 viewer_roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]]] = None,
                 viewers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zone_assignments: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]]] = None):
        """
        The set of arguments for constructing a Project resource.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]] administrator_roles: Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] administrators: A list of administrator users associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input['ProjectConstraintsArgs'] constraints: A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: The project custom properties which are added to all requests in this project.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] machine_naming_template: The naming template to be used for resources provisioned in this project.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]] member_roles: Member users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: A list of member users associated with the project.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[int] operation_timeout: The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        :param pulumi.Input[str] placement_policy: The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        :param pulumi.Input[bool] shared_resources: Specifies whether the resources in this projects are shared or not. If not set default will be used.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]] viewer_roles: Viewer users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] viewers: A list of viewer users associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]] zone_assignments: A list of configurations for zone assignment to a project.
        """
        if administrator_roles is not None:
            pulumi.set(__self__, "administrator_roles", administrator_roles)
        if administrators is not None:
            warnings.warn("""To specify the type of principal, please refer administrator_roles.""", DeprecationWarning)
            pulumi.log.warn("""administrators is deprecated: To specify the type of principal, please refer administrator_roles.""")
        if administrators is not None:
            pulumi.set(__self__, "administrators", administrators)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if machine_naming_template is not None:
            pulumi.set(__self__, "machine_naming_template", machine_naming_template)
        if member_roles is not None:
            pulumi.set(__self__, "member_roles", member_roles)
        if members is not None:
            warnings.warn("""To specify the type of principal, please refer member_roles.""", DeprecationWarning)
            pulumi.log.warn("""members is deprecated: To specify the type of principal, please refer member_roles.""")
        if members is not None:
            pulumi.set(__self__, "members", members)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operation_timeout is not None:
            pulumi.set(__self__, "operation_timeout", operation_timeout)
        if placement_policy is not None:
            pulumi.set(__self__, "placement_policy", placement_policy)
        if shared_resources is not None:
            pulumi.set(__self__, "shared_resources", shared_resources)
        if viewer_roles is not None:
            pulumi.set(__self__, "viewer_roles", viewer_roles)
        if viewers is not None:
            warnings.warn("""To specify the type of principal, please refer viewer_roles.""", DeprecationWarning)
            pulumi.log.warn("""viewers is deprecated: To specify the type of principal, please refer viewer_roles.""")
        if viewers is not None:
            pulumi.set(__self__, "viewers", viewers)
        if zone_assignments is not None:
            pulumi.set(__self__, "zone_assignments", zone_assignments)

    @property
    @pulumi.getter(name="administratorRoles")
    def administrator_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]]]:
        """
        Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        """
        return pulumi.get(self, "administrator_roles")

    @administrator_roles.setter
    def administrator_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]]]):
        pulumi.set(self, "administrator_roles", value)

    @property
    @pulumi.getter
    def administrators(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of administrator users associated with the project. Only administrators can manage project's configuration.
        """
        return pulumi.get(self, "administrators")

    @administrators.setter
    def administrators(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "administrators", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input['ProjectConstraintsArgs']]:
        """
        A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input['ProjectConstraintsArgs']]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The project custom properties which are added to all requests in this project.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="machineNamingTemplate")
    def machine_naming_template(self) -> Optional[pulumi.Input[str]]:
        """
        The naming template to be used for resources provisioned in this project.
        """
        return pulumi.get(self, "machine_naming_template")

    @machine_naming_template.setter
    def machine_naming_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "machine_naming_template", value)

    @property
    @pulumi.getter(name="memberRoles")
    def member_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]:
        """
        Member users or groups associated with the project.
        """
        return pulumi.get(self, "member_roles")

    @member_roles.setter
    def member_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]):
        pulumi.set(self, "member_roles", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of member users associated with the project.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "members", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="operationTimeout")
    def operation_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        """
        return pulumi.get(self, "operation_timeout")

    @operation_timeout.setter
    def operation_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "operation_timeout", value)

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        """
        return pulumi.get(self, "placement_policy")

    @placement_policy.setter
    def placement_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_policy", value)

    @property
    @pulumi.getter(name="sharedResources")
    def shared_resources(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the resources in this projects are shared or not. If not set default will be used.
        """
        return pulumi.get(self, "shared_resources")

    @shared_resources.setter
    def shared_resources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "shared_resources", value)

    @property
    @pulumi.getter(name="viewerRoles")
    def viewer_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]]]:
        """
        Viewer users or groups associated with the project.
        """
        return pulumi.get(self, "viewer_roles")

    @viewer_roles.setter
    def viewer_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]]]):
        pulumi.set(self, "viewer_roles", value)

    @property
    @pulumi.getter
    def viewers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of viewer users associated with the project.
        """
        return pulumi.get(self, "viewers")

    @viewers.setter
    def viewers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "viewers", value)

    @property
    @pulumi.getter(name="zoneAssignments")
    def zone_assignments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]]]:
        """
        A list of configurations for zone assignment to a project.
        """
        return pulumi.get(self, "zone_assignments")

    @zone_assignments.setter
    def zone_assignments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]]]):
        pulumi.set(self, "zone_assignments", value)


@pulumi.input_type
class _ProjectState:
    def __init__(__self__, *,
                 administrator_roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]]] = None,
                 administrators: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 constraints: Optional[pulumi.Input['ProjectConstraintsArgs']] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 machine_naming_template: Optional[pulumi.Input[str]] = None,
                 member_roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operation_timeout: Optional[pulumi.Input[int]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 shared_resources: Optional[pulumi.Input[bool]] = None,
                 viewer_roles: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]]] = None,
                 viewers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zone_assignments: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]]] = None):
        """
        Input properties used for looking up and filtering Project resources.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]] administrator_roles: Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] administrators: A list of administrator users associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input['ProjectConstraintsArgs'] constraints: A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: The project custom properties which are added to all requests in this project.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] machine_naming_template: The naming template to be used for resources provisioned in this project.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]] member_roles: Member users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: A list of member users associated with the project.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[int] operation_timeout: The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        :param pulumi.Input[str] placement_policy: The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        :param pulumi.Input[bool] shared_resources: Specifies whether the resources in this projects are shared or not. If not set default will be used.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]] viewer_roles: Viewer users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] viewers: A list of viewer users associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]] zone_assignments: A list of configurations for zone assignment to a project.
        """
        if administrator_roles is not None:
            pulumi.set(__self__, "administrator_roles", administrator_roles)
        if administrators is not None:
            warnings.warn("""To specify the type of principal, please refer administrator_roles.""", DeprecationWarning)
            pulumi.log.warn("""administrators is deprecated: To specify the type of principal, please refer administrator_roles.""")
        if administrators is not None:
            pulumi.set(__self__, "administrators", administrators)
        if constraints is not None:
            pulumi.set(__self__, "constraints", constraints)
        if custom_properties is not None:
            pulumi.set(__self__, "custom_properties", custom_properties)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if machine_naming_template is not None:
            pulumi.set(__self__, "machine_naming_template", machine_naming_template)
        if member_roles is not None:
            pulumi.set(__self__, "member_roles", member_roles)
        if members is not None:
            warnings.warn("""To specify the type of principal, please refer member_roles.""", DeprecationWarning)
            pulumi.log.warn("""members is deprecated: To specify the type of principal, please refer member_roles.""")
        if members is not None:
            pulumi.set(__self__, "members", members)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if operation_timeout is not None:
            pulumi.set(__self__, "operation_timeout", operation_timeout)
        if placement_policy is not None:
            pulumi.set(__self__, "placement_policy", placement_policy)
        if shared_resources is not None:
            pulumi.set(__self__, "shared_resources", shared_resources)
        if viewer_roles is not None:
            pulumi.set(__self__, "viewer_roles", viewer_roles)
        if viewers is not None:
            warnings.warn("""To specify the type of principal, please refer viewer_roles.""", DeprecationWarning)
            pulumi.log.warn("""viewers is deprecated: To specify the type of principal, please refer viewer_roles.""")
        if viewers is not None:
            pulumi.set(__self__, "viewers", viewers)
        if zone_assignments is not None:
            pulumi.set(__self__, "zone_assignments", zone_assignments)

    @property
    @pulumi.getter(name="administratorRoles")
    def administrator_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]]]:
        """
        Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        """
        return pulumi.get(self, "administrator_roles")

    @administrator_roles.setter
    def administrator_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectAdministratorRoleArgs']]]]):
        pulumi.set(self, "administrator_roles", value)

    @property
    @pulumi.getter
    def administrators(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of administrator users associated with the project. Only administrators can manage project's configuration.
        """
        return pulumi.get(self, "administrators")

    @administrators.setter
    def administrators(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "administrators", value)

    @property
    @pulumi.getter
    def constraints(self) -> Optional[pulumi.Input['ProjectConstraintsArgs']]:
        """
        A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @constraints.setter
    def constraints(self, value: Optional[pulumi.Input['ProjectConstraintsArgs']]):
        pulumi.set(self, "constraints", value)

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        The project custom properties which are added to all requests in this project.
        """
        return pulumi.get(self, "custom_properties")

    @custom_properties.setter
    def custom_properties(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "custom_properties", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="machineNamingTemplate")
    def machine_naming_template(self) -> Optional[pulumi.Input[str]]:
        """
        The naming template to be used for resources provisioned in this project.
        """
        return pulumi.get(self, "machine_naming_template")

    @machine_naming_template.setter
    def machine_naming_template(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "machine_naming_template", value)

    @property
    @pulumi.getter(name="memberRoles")
    def member_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]:
        """
        Member users or groups associated with the project.
        """
        return pulumi.get(self, "member_roles")

    @member_roles.setter
    def member_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectMemberRoleArgs']]]]):
        pulumi.set(self, "member_roles", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of member users associated with the project.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "members", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="operationTimeout")
    def operation_timeout(self) -> Optional[pulumi.Input[int]]:
        """
        The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        """
        return pulumi.get(self, "operation_timeout")

    @operation_timeout.setter
    def operation_timeout(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "operation_timeout", value)

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> Optional[pulumi.Input[str]]:
        """
        The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        """
        return pulumi.get(self, "placement_policy")

    @placement_policy.setter
    def placement_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "placement_policy", value)

    @property
    @pulumi.getter(name="sharedResources")
    def shared_resources(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the resources in this projects are shared or not. If not set default will be used.
        """
        return pulumi.get(self, "shared_resources")

    @shared_resources.setter
    def shared_resources(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "shared_resources", value)

    @property
    @pulumi.getter(name="viewerRoles")
    def viewer_roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]]]:
        """
        Viewer users or groups associated with the project.
        """
        return pulumi.get(self, "viewer_roles")

    @viewer_roles.setter
    def viewer_roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectViewerRoleArgs']]]]):
        pulumi.set(self, "viewer_roles", value)

    @property
    @pulumi.getter
    def viewers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of viewer users associated with the project.
        """
        return pulumi.get(self, "viewers")

    @viewers.setter
    def viewers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "viewers", value)

    @property
    @pulumi.getter(name="zoneAssignments")
    def zone_assignments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]]]:
        """
        A list of configurations for zone assignment to a project.
        """
        return pulumi.get(self, "zone_assignments")

    @zone_assignments.setter
    def zone_assignments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectZoneAssignmentArgs']]]]):
        pulumi.set(self, "zone_assignments", value)


class Project(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 administrator_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectAdministratorRoleArgs']]]]] = None,
                 administrators: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 constraints: Optional[pulumi.Input[pulumi.InputType['ProjectConstraintsArgs']]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 machine_naming_template: Optional[pulumi.Input[str]] = None,
                 member_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectMemberRoleArgs']]]]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operation_timeout: Optional[pulumi.Input[int]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 shared_resources: Optional[pulumi.Input[bool]] = None,
                 viewer_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectViewerRoleArgs']]]]] = None,
                 viewers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zone_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectZoneAssignmentArgs']]]]] = None,
                 __props__=None):
        """
        ## Example Usage

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectAdministratorRoleArgs']]]] administrator_roles: Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] administrators: A list of administrator users associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input[pulumi.InputType['ProjectConstraintsArgs']] constraints: A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: The project custom properties which are added to all requests in this project.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] machine_naming_template: The naming template to be used for resources provisioned in this project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectMemberRoleArgs']]]] member_roles: Member users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: A list of member users associated with the project.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[int] operation_timeout: The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        :param pulumi.Input[str] placement_policy: The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        :param pulumi.Input[bool] shared_resources: Specifies whether the resources in this projects are shared or not. If not set default will be used.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectViewerRoleArgs']]]] viewer_roles: Viewer users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] viewers: A list of viewer users associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectZoneAssignmentArgs']]]] zone_assignments: A list of configurations for zone assignment to a project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ProjectArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        :param str resource_name: The name of the resource.
        :param ProjectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 administrator_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectAdministratorRoleArgs']]]]] = None,
                 administrators: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 constraints: Optional[pulumi.Input[pulumi.InputType['ProjectConstraintsArgs']]] = None,
                 custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 machine_naming_template: Optional[pulumi.Input[str]] = None,
                 member_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectMemberRoleArgs']]]]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 operation_timeout: Optional[pulumi.Input[int]] = None,
                 placement_policy: Optional[pulumi.Input[str]] = None,
                 shared_resources: Optional[pulumi.Input[bool]] = None,
                 viewer_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectViewerRoleArgs']]]]] = None,
                 viewers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 zone_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectZoneAssignmentArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectArgs.__new__(ProjectArgs)

            __props__.__dict__["administrator_roles"] = administrator_roles
            if administrators is not None and not opts.urn:
                warnings.warn("""To specify the type of principal, please refer administrator_roles.""", DeprecationWarning)
                pulumi.log.warn("""administrators is deprecated: To specify the type of principal, please refer administrator_roles.""")
            __props__.__dict__["administrators"] = administrators
            __props__.__dict__["constraints"] = constraints
            __props__.__dict__["custom_properties"] = custom_properties
            __props__.__dict__["description"] = description
            __props__.__dict__["machine_naming_template"] = machine_naming_template
            __props__.__dict__["member_roles"] = member_roles
            if members is not None and not opts.urn:
                warnings.warn("""To specify the type of principal, please refer member_roles.""", DeprecationWarning)
                pulumi.log.warn("""members is deprecated: To specify the type of principal, please refer member_roles.""")
            __props__.__dict__["members"] = members
            __props__.__dict__["name"] = name
            __props__.__dict__["operation_timeout"] = operation_timeout
            __props__.__dict__["placement_policy"] = placement_policy
            __props__.__dict__["shared_resources"] = shared_resources
            __props__.__dict__["viewer_roles"] = viewer_roles
            if viewers is not None and not opts.urn:
                warnings.warn("""To specify the type of principal, please refer viewer_roles.""", DeprecationWarning)
                pulumi.log.warn("""viewers is deprecated: To specify the type of principal, please refer viewer_roles.""")
            __props__.__dict__["viewers"] = viewers
            __props__.__dict__["zone_assignments"] = zone_assignments
        super(Project, __self__).__init__(
            'vra:project/project:Project',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            administrator_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectAdministratorRoleArgs']]]]] = None,
            administrators: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            constraints: Optional[pulumi.Input[pulumi.InputType['ProjectConstraintsArgs']]] = None,
            custom_properties: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            description: Optional[pulumi.Input[str]] = None,
            machine_naming_template: Optional[pulumi.Input[str]] = None,
            member_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectMemberRoleArgs']]]]] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            operation_timeout: Optional[pulumi.Input[int]] = None,
            placement_policy: Optional[pulumi.Input[str]] = None,
            shared_resources: Optional[pulumi.Input[bool]] = None,
            viewer_roles: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectViewerRoleArgs']]]]] = None,
            viewers: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            zone_assignments: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectZoneAssignmentArgs']]]]] = None) -> 'Project':
        """
        Get an existing Project resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectAdministratorRoleArgs']]]] administrator_roles: Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] administrators: A list of administrator users associated with the project. Only administrators can manage project's configuration.
        :param pulumi.Input[pulumi.InputType['ProjectConstraintsArgs']] constraints: A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        :param pulumi.Input[Mapping[str, Any]] custom_properties: The project custom properties which are added to all requests in this project.
        :param pulumi.Input[str] description: A human-friendly description.
        :param pulumi.Input[str] machine_naming_template: The naming template to be used for resources provisioned in this project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectMemberRoleArgs']]]] member_roles: Member users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] members: A list of member users associated with the project.
        :param pulumi.Input[str] name: A human-friendly name used as an identifier in APIs that support this option.
        :param pulumi.Input[int] operation_timeout: The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        :param pulumi.Input[str] placement_policy: The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        :param pulumi.Input[bool] shared_resources: Specifies whether the resources in this projects are shared or not. If not set default will be used.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectViewerRoleArgs']]]] viewer_roles: Viewer users or groups associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] viewers: A list of viewer users associated with the project.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['ProjectZoneAssignmentArgs']]]] zone_assignments: A list of configurations for zone assignment to a project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectState.__new__(_ProjectState)

        __props__.__dict__["administrator_roles"] = administrator_roles
        __props__.__dict__["administrators"] = administrators
        __props__.__dict__["constraints"] = constraints
        __props__.__dict__["custom_properties"] = custom_properties
        __props__.__dict__["description"] = description
        __props__.__dict__["machine_naming_template"] = machine_naming_template
        __props__.__dict__["member_roles"] = member_roles
        __props__.__dict__["members"] = members
        __props__.__dict__["name"] = name
        __props__.__dict__["operation_timeout"] = operation_timeout
        __props__.__dict__["placement_policy"] = placement_policy
        __props__.__dict__["shared_resources"] = shared_resources
        __props__.__dict__["viewer_roles"] = viewer_roles
        __props__.__dict__["viewers"] = viewers
        __props__.__dict__["zone_assignments"] = zone_assignments
        return Project(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="administratorRoles")
    def administrator_roles(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectAdministratorRole']]]:
        """
        Administrator users or groups associated with the project. Only administrators can manage project's configuration.
        """
        return pulumi.get(self, "administrator_roles")

    @property
    @pulumi.getter
    def administrators(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of administrator users associated with the project. Only administrators can manage project's configuration.
        """
        return pulumi.get(self, "administrators")

    @property
    @pulumi.getter
    def constraints(self) -> pulumi.Output[Optional['outputs.ProjectConstraints']]:
        """
        A list of storage, network, and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> pulumi.Output[Optional[Mapping[str, Any]]]:
        """
        The project custom properties which are added to all requests in this project.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="machineNamingTemplate")
    def machine_naming_template(self) -> pulumi.Output[Optional[str]]:
        """
        The naming template to be used for resources provisioned in this project.
        """
        return pulumi.get(self, "machine_naming_template")

    @property
    @pulumi.getter(name="memberRoles")
    def member_roles(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectMemberRole']]]:
        """
        Member users or groups associated with the project.
        """
        return pulumi.get(self, "member_roles")

    @property
    @pulumi.getter
    def members(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of member users associated with the project.
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        A human-friendly name used as an identifier in APIs that support this option.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="operationTimeout")
    def operation_timeout(self) -> pulumi.Output[Optional[int]]:
        """
        The timeout that should be used for cloud template operations and provisioning tasks. The timeout is measured in seconds.
        """
        return pulumi.get(self, "operation_timeout")

    @property
    @pulumi.getter(name="placementPolicy")
    def placement_policy(self) -> pulumi.Output[Optional[str]]:
        """
        The placement policy that will be applied when selecting a cloud zone for provisioning. Must be one of `DEFAULT` or `SPREAD`.
        """
        return pulumi.get(self, "placement_policy")

    @property
    @pulumi.getter(name="sharedResources")
    def shared_resources(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether the resources in this projects are shared or not. If not set default will be used.
        """
        return pulumi.get(self, "shared_resources")

    @property
    @pulumi.getter(name="viewerRoles")
    def viewer_roles(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectViewerRole']]]:
        """
        Viewer users or groups associated with the project.
        """
        return pulumi.get(self, "viewer_roles")

    @property
    @pulumi.getter
    def viewers(self) -> pulumi.Output[Optional[Sequence[str]]]:
        """
        A list of viewer users associated with the project.
        """
        return pulumi.get(self, "viewers")

    @property
    @pulumi.getter(name="zoneAssignments")
    def zone_assignments(self) -> pulumi.Output[Optional[Sequence['outputs.ProjectZoneAssignment']]]:
        """
        A list of configurations for zone assignment to a project.
        """
        return pulumi.get(self, "zone_assignments")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetEnumerationVSphereResult',
    'AwaitableGetEnumerationVSphereResult',
    'get_enumeration_v_sphere',
    'get_enumeration_v_sphere_output',
]

@pulumi.output_type
class GetEnumerationVSphereResult:
    """
    A collection of values returned by getEnumerationVSphere.
    """
    def __init__(__self__, accept_self_signed_cert=None, dcid=None, hostname=None, id=None, password=None, regions=None, username=None):
        if accept_self_signed_cert and not isinstance(accept_self_signed_cert, bool):
            raise TypeError("Expected argument 'accept_self_signed_cert' to be a bool")
        pulumi.set(__self__, "accept_self_signed_cert", accept_self_signed_cert)
        if dcid and not isinstance(dcid, str):
            raise TypeError("Expected argument 'dcid' to be a str")
        pulumi.set(__self__, "dcid", dcid)
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @property
    @pulumi.getter(name="acceptSelfSignedCert")
    def accept_self_signed_cert(self) -> Optional[bool]:
        return pulumi.get(self, "accept_self_signed_cert")

    @property
    @pulumi.getter
    def dcid(self) -> Optional[str]:
        return pulumi.get(self, "dcid")

    @property
    @pulumi.getter
    def hostname(self) -> str:
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def password(self) -> str:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter
    def regions(self) -> Sequence[str]:
        """
        A set of datacenter managed object reference identifiers to enable provisioning on. Example: Datacenter:datacenter-2
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter
    def username(self) -> str:
        return pulumi.get(self, "username")


class AwaitableGetEnumerationVSphereResult(GetEnumerationVSphereResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnumerationVSphereResult(
            accept_self_signed_cert=self.accept_self_signed_cert,
            dcid=self.dcid,
            hostname=self.hostname,
            id=self.id,
            password=self.password,
            regions=self.regions,
            username=self.username)


def get_enumeration_v_sphere(accept_self_signed_cert: Optional[bool] = None,
                             dcid: Optional[str] = None,
                             hostname: Optional[str] = None,
                             password: Optional[str] = None,
                             username: Optional[str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnumerationVSphereResult:
    """
    ## Example Usage


    :param bool accept_self_signed_cert: Accept self signed certificate when connecting to vSphere. Example: false
    :param str dcid: ID of a data collector vm deployed in the on premise infrastructure. Example: d5316b00-f3b8-4895-9e9a-c4b98649c2ca
    :param str hostname: Host name for the cloud account endpoint. Example: dc1-lnd.mycompany.com
    :param str password: Password for the user used to authenticate with the cloud Account
    :param str username: Username to authenticate with the cloud account
    """
    __args__ = dict()
    __args__['acceptSelfSignedCert'] = accept_self_signed_cert
    __args__['dcid'] = dcid
    __args__['hostname'] = hostname
    __args__['password'] = password
    __args__['username'] = username
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:region/getEnumerationVSphere:getEnumerationVSphere', __args__, opts=opts, typ=GetEnumerationVSphereResult).value

    return AwaitableGetEnumerationVSphereResult(
        accept_self_signed_cert=__ret__.accept_self_signed_cert,
        dcid=__ret__.dcid,
        hostname=__ret__.hostname,
        id=__ret__.id,
        password=__ret__.password,
        regions=__ret__.regions,
        username=__ret__.username)


@_utilities.lift_output_func(get_enumeration_v_sphere)
def get_enumeration_v_sphere_output(accept_self_signed_cert: Optional[pulumi.Input[Optional[bool]]] = None,
                                    dcid: Optional[pulumi.Input[Optional[str]]] = None,
                                    hostname: Optional[pulumi.Input[str]] = None,
                                    password: Optional[pulumi.Input[str]] = None,
                                    username: Optional[pulumi.Input[str]] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnumerationVSphereResult]:
    """
    ## Example Usage


    :param bool accept_self_signed_cert: Accept self signed certificate when connecting to vSphere. Example: false
    :param str dcid: ID of a data collector vm deployed in the on premise infrastructure. Example: d5316b00-f3b8-4895-9e9a-c4b98649c2ca
    :param str hostname: Host name for the cloud account endpoint. Example: dc1-lnd.mycompany.com
    :param str password: Password for the user used to authenticate with the cloud Account
    :param str username: Username to authenticate with the cloud account
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'ProjectAdministratorRole',
    'ProjectConstraints',
    'ProjectConstraintsExtensibility',
    'ProjectConstraintsNetwork',
    'ProjectConstraintsStorage',
    'ProjectMemberRole',
    'ProjectViewerRole',
    'ProjectZoneAssignment',
    'GetProjectAdministratorRoleResult',
    'GetProjectConstraintsResult',
    'GetProjectConstraintsExtensibilityResult',
    'GetProjectConstraintsNetworkResult',
    'GetProjectConstraintsStorageResult',
    'GetProjectMemberRoleResult',
    'GetProjectViewerRoleResult',
    'GetProjectZoneAssignmentResult',
]

@pulumi.output_type
class ProjectAdministratorRole(dict):
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class ProjectConstraints(dict):
    def __init__(__self__, *,
                 extensibilities: Optional[Sequence['outputs.ProjectConstraintsExtensibility']] = None,
                 networks: Optional[Sequence['outputs.ProjectConstraintsNetwork']] = None,
                 storages: Optional[Sequence['outputs.ProjectConstraintsStorage']] = None):
        if extensibilities is not None:
            pulumi.set(__self__, "extensibilities", extensibilities)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter
    def extensibilities(self) -> Optional[Sequence['outputs.ProjectConstraintsExtensibility']]:
        return pulumi.get(self, "extensibilities")

    @property
    @pulumi.getter
    def networks(self) -> Optional[Sequence['outputs.ProjectConstraintsNetwork']]:
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter
    def storages(self) -> Optional[Sequence['outputs.ProjectConstraintsStorage']]:
        return pulumi.get(self, "storages")


@pulumi.output_type
class ProjectConstraintsExtensibility(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class ProjectConstraintsNetwork(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class ProjectConstraintsStorage(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class ProjectMemberRole(dict):
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class ProjectViewerRole(dict):
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class ProjectZoneAssignment(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "zoneId":
            suggest = "zone_id"
        elif key == "cpuLimit":
            suggest = "cpu_limit"
        elif key == "maxInstances":
            suggest = "max_instances"
        elif key == "memoryLimitMb":
            suggest = "memory_limit_mb"
        elif key == "storageLimitGb":
            suggest = "storage_limit_gb"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ProjectZoneAssignment. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ProjectZoneAssignment.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ProjectZoneAssignment.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 zone_id: str,
                 cpu_limit: Optional[int] = None,
                 max_instances: Optional[int] = None,
                 memory_limit_mb: Optional[int] = None,
                 priority: Optional[int] = None,
                 storage_limit_gb: Optional[int] = None):
        pulumi.set(__self__, "zone_id", zone_id)
        if cpu_limit is not None:
            pulumi.set(__self__, "cpu_limit", cpu_limit)
        if max_instances is not None:
            pulumi.set(__self__, "max_instances", max_instances)
        if memory_limit_mb is not None:
            pulumi.set(__self__, "memory_limit_mb", memory_limit_mb)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if storage_limit_gb is not None:
            pulumi.set(__self__, "storage_limit_gb", storage_limit_gb)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> Optional[int]:
        return pulumi.get(self, "cpu_limit")

    @property
    @pulumi.getter(name="maxInstances")
    def max_instances(self) -> Optional[int]:
        return pulumi.get(self, "max_instances")

    @property
    @pulumi.getter(name="memoryLimitMb")
    def memory_limit_mb(self) -> Optional[int]:
        return pulumi.get(self, "memory_limit_mb")

    @property
    @pulumi.getter
    def priority(self) -> Optional[int]:
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="storageLimitGb")
    def storage_limit_gb(self) -> Optional[int]:
        return pulumi.get(self, "storage_limit_gb")


@pulumi.output_type
class GetProjectAdministratorRoleResult(dict):
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetProjectConstraintsResult(dict):
    def __init__(__self__, *,
                 extensibilities: Optional[Sequence['outputs.GetProjectConstraintsExtensibilityResult']] = None,
                 networks: Optional[Sequence['outputs.GetProjectConstraintsNetworkResult']] = None,
                 storages: Optional[Sequence['outputs.GetProjectConstraintsStorageResult']] = None):
        if extensibilities is not None:
            pulumi.set(__self__, "extensibilities", extensibilities)
        if networks is not None:
            pulumi.set(__self__, "networks", networks)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter
    def extensibilities(self) -> Optional[Sequence['outputs.GetProjectConstraintsExtensibilityResult']]:
        return pulumi.get(self, "extensibilities")

    @property
    @pulumi.getter
    def networks(self) -> Optional[Sequence['outputs.GetProjectConstraintsNetworkResult']]:
        return pulumi.get(self, "networks")

    @property
    @pulumi.getter
    def storages(self) -> Optional[Sequence['outputs.GetProjectConstraintsStorageResult']]:
        return pulumi.get(self, "storages")


@pulumi.output_type
class GetProjectConstraintsExtensibilityResult(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class GetProjectConstraintsNetworkResult(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class GetProjectConstraintsStorageResult(dict):
    def __init__(__self__, *,
                 expression: str,
                 mandatory: bool):
        pulumi.set(__self__, "expression", expression)
        pulumi.set(__self__, "mandatory", mandatory)

    @property
    @pulumi.getter
    def expression(self) -> str:
        return pulumi.get(self, "expression")

    @property
    @pulumi.getter
    def mandatory(self) -> bool:
        return pulumi.get(self, "mandatory")


@pulumi.output_type
class GetProjectMemberRoleResult(dict):
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetProjectViewerRoleResult(dict):
    def __init__(__self__, *,
                 email: str,
                 type: Optional[str] = None):
        pulumi.set(__self__, "email", email)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter
    def type(self) -> Optional[str]:
        return pulumi.get(self, "type")


@pulumi.output_type
class GetProjectZoneAssignmentResult(dict):
    def __init__(__self__, *,
                 cpu_limit: int,
                 max_instances: int,
                 memory_limit_mb: int,
                 priority: int,
                 storage_limit_gb: int,
                 zone_id: str):
        pulumi.set(__self__, "cpu_limit", cpu_limit)
        pulumi.set(__self__, "max_instances", max_instances)
        pulumi.set(__self__, "memory_limit_mb", memory_limit_mb)
        pulumi.set(__self__, "priority", priority)
        pulumi.set(__self__, "storage_limit_gb", storage_limit_gb)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="cpuLimit")
    def cpu_limit(self) -> int:
        return pulumi.get(self, "cpu_limit")

    @property
    @pulumi.getter(name="maxInstances")
    def max_instances(self) -> int:
        return pulumi.get(self, "max_instances")

    @property
    @pulumi.getter(name="memoryLimitMb")
    def memory_limit_mb(self) -> int:
        return pulumi.get(self, "memory_limit_mb")

    @property
    @pulumi.getter
    def priority(self) -> int:
        return pulumi.get(self, "priority")

    @property
    @pulumi.getter(name="storageLimitGb")
    def storage_limit_gb(self) -> int:
        return pulumi.get(self, "storage_limit_gb")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        return pulumi.get(self, "zone_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ContentSourceConfig',
]

@pulumi.output_type
class ContentSourceConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "integrationId":
            suggest = "integration_id"
        elif key == "projectName":
            suggest = "project_name"
        elif key == "contentType":
            suggest = "content_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ContentSourceConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ContentSourceConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ContentSourceConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 integration_id: str,
                 path: str,
                 project_name: str,
                 branch: Optional[str] = None,
                 content_type: Optional[str] = None,
                 repository: Optional[str] = None):
        """
        :param str integration_id: Content source integration id as seen in vRA integrations.
        :param str path: Path to refer to in the content source repository and branch.
        :param str project_name: Name of the project.
        :param str branch: Content source branch name.
        :param str content_type: Content source type. Supported values are `BLUEPRINT`, `IMAGE`, `ABX_SCRIPTS`, `TERRAFORM_CONFIGURATION`.
        :param str repository: Content source repository.
        """
        pulumi.set(__self__, "integration_id", integration_id)
        pulumi.set(__self__, "path", path)
        pulumi.set(__self__, "project_name", project_name)
        if branch is not None:
            pulumi.set(__self__, "branch", branch)
        if content_type is not None:
            pulumi.set(__self__, "content_type", content_type)
        if repository is not None:
            pulumi.set(__self__, "repository", repository)

    @property
    @pulumi.getter(name="integrationId")
    def integration_id(self) -> str:
        """
        Content source integration id as seen in vRA integrations.
        """
        return pulumi.get(self, "integration_id")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        Path to refer to in the content source repository and branch.
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> str:
        """
        Name of the project.
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def branch(self) -> Optional[str]:
        """
        Content source branch name.
        """
        return pulumi.get(self, "branch")

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> Optional[str]:
        """
        Content source type. Supported values are `BLUEPRINT`, `IMAGE`, `ABX_SCRIPTS`, `TERRAFORM_CONFIGURATION`.
        """
        return pulumi.get(self, "content_type")

    @property
    @pulumi.getter
    def repository(self) -> Optional[str]:
        """
        Content source repository.
        """
        return pulumi.get(self, "repository")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNetworkResult',
    'AwaitableGetNetworkResult',
    'get_network',
    'get_network_output',
]

@pulumi.output_type
class GetNetworkResult:
    """
    A collection of values returned by getNetwork.
    """
    def __init__(__self__, cidr=None, constraints=None, custom_properties=None, deployment_id=None, description=None, external_id=None, external_zone_id=None, id=None, links=None, name=None, organization_id=None, outbound_access=None, owner=None, project_id=None, self_link=None, tags=None, updated_at=None):
        if cidr and not isinstance(cidr, str):
            raise TypeError("Expected argument 'cidr' to be a str")
        pulumi.set(__self__, "cidr", cidr)
        if constraints and not isinstance(constraints, list):
            raise TypeError("Expected argument 'constraints' to be a list")
        pulumi.set(__self__, "constraints", constraints)
        if custom_properties and not isinstance(custom_properties, dict):
            raise TypeError("Expected argument 'custom_properties' to be a dict")
        pulumi.set(__self__, "custom_properties", custom_properties)
        if deployment_id and not isinstance(deployment_id, str):
            raise TypeError("Expected argument 'deployment_id' to be a str")
        pulumi.set(__self__, "deployment_id", deployment_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_zone_id and not isinstance(external_zone_id, str):
            raise TypeError("Expected argument 'external_zone_id' to be a str")
        pulumi.set(__self__, "external_zone_id", external_zone_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if organization_id and not isinstance(organization_id, str):
            raise TypeError("Expected argument 'organization_id' to be a str")
        pulumi.set(__self__, "organization_id", organization_id)
        if outbound_access and not isinstance(outbound_access, bool):
            raise TypeError("Expected argument 'outbound_access' to be a bool")
        pulumi.set(__self__, "outbound_access", outbound_access)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if self_link and not isinstance(self_link, str):
            raise TypeError("Expected argument 'self_link' to be a str")
        pulumi.set(__self__, "self_link", self_link)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter
    def cidr(self) -> str:
        """
        IPv4 address range of the network in CIDR format.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter
    def constraints(self) -> Optional[Sequence['outputs.GetNetworkConstraintResult']]:
        """
        List of storage, network and extensibility constraints to be applied when provisioning through this project.
        """
        return pulumi.get(self, "constraints")

    @property
    @pulumi.getter(name="customProperties")
    def custom_properties(self) -> Mapping[str, Any]:
        """
        Additional properties that may be used to extend the base resource.
        """
        return pulumi.get(self, "custom_properties")

    @property
    @pulumi.getter(name="deploymentId")
    def deployment_id(self) -> str:
        """
        Deployment id that is associated with this resource.
        """
        return pulumi.get(self, "deployment_id")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        A human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalZoneId")
    def external_zone_id(self) -> str:
        """
        The external zoneId of the resource.
        """
        return pulumi.get(self, "external_zone_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetNetworkLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="outboundAccess")
    def outbound_access(self) -> bool:
        """
        Flag to indicate if the network needs to have outbound access or not. Default is true. This field will be ignored if there is proper input for networkType customProperty
        """
        return pulumi.get(self, "outbound_access")

    @property
    @pulumi.getter
    def owner(self) -> str:
        """
        Email of the user that owns the entity.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> str:
        """
        The id of the project this resource belongs to.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="selfLink")
    def self_link(self) -> str:
        """
        Self link of this request.
        """
        return pulumi.get(self, "self_link")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetNetworkTagResult']:
        """
        A set of tag keys and optional values that were set on this resource.
        example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        return pulumi.get(self, "updated_at")


class AwaitableGetNetworkResult(GetNetworkResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNetworkResult(
            cidr=self.cidr,
            constraints=self.constraints,
            custom_properties=self.custom_properties,
            deployment_id=self.deployment_id,
            description=self.description,
            external_id=self.external_id,
            external_zone_id=self.external_zone_id,
            id=self.id,
            links=self.links,
            name=self.name,
            organization_id=self.organization_id,
            outbound_access=self.outbound_access,
            owner=self.owner,
            project_id=self.project_id,
            self_link=self.self_link,
            tags=self.tags,
            updated_at=self.updated_at)


def get_network(constraints: Optional[Sequence[pulumi.InputType['GetNetworkConstraintArgs']]] = None,
                id: Optional[str] = None,
                name: Optional[str] = None,
                tags: Optional[Sequence[pulumi.InputType['GetNetworkTagArgs']]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNetworkResult:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: network.Network"
    description: |-
      Provides a data lookup for vra_network.
    ---

    # Data Source: network.Network
    ## Example Usage
    ### S

    This is an example of how to read a network data source.

    ```python
    import pulumi
    import pulumi_vra as vra

    test_network = vra.network.get_network(name=var["network_name"])
    ```


    :param Sequence[pulumi.InputType['GetNetworkConstraintArgs']] constraints: List of storage, network and extensibility constraints to be applied when provisioning through this project.
    :param str id: The id of the image profile instance.
    :param str name: A human-friendly name used as an identifier in APIs that support this option.
    :param Sequence[pulumi.InputType['GetNetworkTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    __args__ = dict()
    __args__['constraints'] = constraints
    __args__['id'] = id
    __args__['name'] = name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:network/getNetwork:getNetwork', __args__, opts=opts, typ=GetNetworkResult).value

    return AwaitableGetNetworkResult(
        cidr=__ret__.cidr,
        constraints=__ret__.constraints,
        custom_properties=__ret__.custom_properties,
        deployment_id=__ret__.deployment_id,
        description=__ret__.description,
        external_id=__ret__.external_id,
        external_zone_id=__ret__.external_zone_id,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        organization_id=__ret__.organization_id,
        outbound_access=__ret__.outbound_access,
        owner=__ret__.owner,
        project_id=__ret__.project_id,
        self_link=__ret__.self_link,
        tags=__ret__.tags,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_network)
def get_network_output(constraints: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetNetworkConstraintArgs']]]]] = None,
                       id: Optional[pulumi.Input[Optional[str]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       tags: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetNetworkTagArgs']]]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNetworkResult]:
    """
    ## ---layout: "vra"

    page_title: "VMware vRealize Automation: network.Network"
    description: |-
      Provides a data lookup for vra_network.
    ---

    # Data Source: network.Network
    ## Example Usage
    ### S

    This is an example of how to read a network data source.

    ```python
    import pulumi
    import pulumi_vra as vra

    test_network = vra.network.get_network(name=var["network_name"])
    ```


    :param Sequence[pulumi.InputType['GetNetworkConstraintArgs']] constraints: List of storage, network and extensibility constraints to be applied when provisioning through this project.
    :param str id: The id of the image profile instance.
    :param str name: A human-friendly name used as an identifier in APIs that support this option.
    :param Sequence[pulumi.InputType['GetNetworkTagArgs']] tags: A set of tag keys and optional values that were set on this resource.
           example:[ { "key" : "ownedBy", "value": "Rainpole" } ]
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetStoragePolicyVSphereResult',
    'AwaitableGetStoragePolicyVSphereResult',
    'get_storage_policy_v_sphere',
    'get_storage_policy_v_sphere_output',
]

@pulumi.output_type
class GetStoragePolicyVSphereResult:
    """
    A collection of values returned by getStoragePolicyVSphere.
    """
    def __init__(__self__, cloud_account_ids=None, created_at=None, external_id=None, external_region_id=None, filter=None, id=None, links=None, name=None, org_id=None, updated_at=None):
        if cloud_account_ids and not isinstance(cloud_account_ids, list):
            raise TypeError("Expected argument 'cloud_account_ids' to be a list")
        pulumi.set(__self__, "cloud_account_ids", cloud_account_ids)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if external_region_id and not isinstance(external_region_id, str):
            raise TypeError("Expected argument 'external_region_id' to be a str")
        pulumi.set(__self__, "external_region_id", external_region_id)
        if filter and not isinstance(filter, str):
            raise TypeError("Expected argument 'filter' to be a str")
        pulumi.set(__self__, "filter", filter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if links and not isinstance(links, list):
            raise TypeError("Expected argument 'links' to be a list")
        pulumi.set(__self__, "links", links)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="cloudAccountIds")
    def cloud_account_ids(self) -> Sequence[str]:
        """
        Set of ids of the cloud accounts this entity belongs to.
        """
        return pulumi.get(self, "cloud_account_ids")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        """
        Date when the entity was created. The date is in ISO 6801 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        """
        External entity Id on the provider side.
        """
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter(name="externalRegionId")
    def external_region_id(self) -> str:
        """
        The id of the region for which this entity is defined.
        """
        return pulumi.get(self, "external_region_id")

    @property
    @pulumi.getter
    def filter(self) -> Optional[str]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def links(self) -> Sequence['outputs.GetStoragePolicyVSphereLinkResult']:
        """
        HATEOAS of the entity
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A human-friendly name used as an identifier in APIs that support this option.  Only one of 'filter', 'id', 'name' or 'region_id' must be specified.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> str:
        """
        The id of the organization this entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        """
        Date when the entity was last updated. The date is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetStoragePolicyVSphereResult(GetStoragePolicyVSphereResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStoragePolicyVSphereResult(
            cloud_account_ids=self.cloud_account_ids,
            created_at=self.created_at,
            external_id=self.external_id,
            external_region_id=self.external_region_id,
            filter=self.filter,
            id=self.id,
            links=self.links,
            name=self.name,
            org_id=self.org_id,
            updated_at=self.updated_at)


def get_storage_policy_v_sphere(filter: Optional[str] = None,
                                id: Optional[str] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStoragePolicyVSphereResult:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup fabric vSphere storage policies.

    **Fabric vSphere storage policy by Id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(id=var["fabric_storage_policy_vsphere_id"])
    ```

    **Fabric vSphere storage policy by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(filter=f"name eq '{var['name']}'")
    ```

    A fabric vSphere storage policy supports the following arguments:


    :param str filter: Search criteria to narrow down the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    :param str id: The id of the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    """
    __args__ = dict()
    __args__['filter'] = filter
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('vra:fabric/getStoragePolicyVSphere:getStoragePolicyVSphere', __args__, opts=opts, typ=GetStoragePolicyVSphereResult).value

    return AwaitableGetStoragePolicyVSphereResult(
        cloud_account_ids=__ret__.cloud_account_ids,
        created_at=__ret__.created_at,
        external_id=__ret__.external_id,
        external_region_id=__ret__.external_region_id,
        filter=__ret__.filter,
        id=__ret__.id,
        links=__ret__.links,
        name=__ret__.name,
        org_id=__ret__.org_id,
        updated_at=__ret__.updated_at)


@_utilities.lift_output_func(get_storage_policy_v_sphere)
def get_storage_policy_v_sphere_output(filter: Optional[pulumi.Input[Optional[str]]] = None,
                                       id: Optional[pulumi.Input[Optional[str]]] = None,
                                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetStoragePolicyVSphereResult]:
    """
    ## Example Usage
    ### S
    This is an example of how to lookup fabric vSphere storage policies.

    **Fabric vSphere storage policy by Id:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(id=var["fabric_storage_policy_vsphere_id"])
    ```

    **Fabric vSphere storage policy by filter query:**

    ```python
    import pulumi
    import pulumi_vra as vra

    this = vra.fabric.get_storage_policy_v_sphere(filter=f"name eq '{var['name']}'")
    ```

    A fabric vSphere storage policy supports the following arguments:


    :param str filter: Search criteria to narrow down the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    :param str id: The id of the fabric vSphere storage policy. Only one of 'filter' or 'id' must be specified.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GcpArgs', 'Gcp']

@pulumi.input_type
class GcpArgs:
    def __init__(__self__, *,
                 client_email: pulumi.Input[str],
                 private_key: pulumi.Input[str],
                 private_key_id: pulumi.Input[str],
                 project_id: pulumi.Input[str],
                 regions: pulumi.Input[Sequence[pulumi.Input[str]]],
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]]] = None):
        """
        The set of arguments for constructing a Gcp resource.
        :param pulumi.Input[str] client_email: GCP Client email.
        :param pulumi.Input[str] private_key: GCP Private key.
        :param pulumi.Input[str] private_key_id: GCP Private key ID.
        :param pulumi.Input[str] project_id: GCP Project ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Name of GCP cloud account.
        :param pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        pulumi.set(__self__, "client_email", client_email)
        pulumi.set(__self__, "private_key", private_key)
        pulumi.set(__self__, "private_key_id", private_key_id)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "regions", regions)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter(name="clientEmail")
    def client_email(self) -> pulumi.Input[str]:
        """
        GCP Client email.
        """
        return pulumi.get(self, "client_email")

    @client_email.setter
    def client_email(self, value: pulumi.Input[str]):
        pulumi.set(self, "client_email", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Input[str]:
        """
        GCP Private key.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: pulumi.Input[str]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="privateKeyId")
    def private_key_id(self) -> pulumi.Input[str]:
        """
        GCP Private key ID.
        """
        return pulumi.get(self, "private_key_id")

    @private_key_id.setter
    def private_key_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "private_key_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[str]:
        """
        GCP Project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Input[Sequence[pulumi.Input[str]]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: pulumi.Input[Sequence[pulumi.Input[str]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of GCP cloud account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]]]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _GcpState:
    def __init__(__self__, *,
                 client_email: Optional[pulumi.Input[str]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 links: Optional[pulumi.Input[Sequence[pulumi.Input['GcpLinkArgs']]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 org_id: Optional[pulumi.Input[str]] = None,
                 owner: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 private_key_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Gcp resources.
        :param pulumi.Input[str] client_email: GCP Client email.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input['GcpLinkArgs']]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Name of GCP cloud account.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] private_key: GCP Private key.
        :param pulumi.Input[str] private_key_id: GCP Private key ID.
        :param pulumi.Input[str] project_id: GCP Project ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        if client_email is not None:
            pulumi.set(__self__, "client_email", client_email)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if links is not None:
            pulumi.set(__self__, "links", links)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if owner is not None:
            pulumi.set(__self__, "owner", owner)
        if private_key is not None:
            pulumi.set(__self__, "private_key", private_key)
        if private_key_id is not None:
            pulumi.set(__self__, "private_key_id", private_key_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if regions is not None:
            pulumi.set(__self__, "regions", regions)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="clientEmail")
    def client_email(self) -> Optional[pulumi.Input[str]]:
        """
        GCP Client email.
        """
        return pulumi.get(self, "client_email")

    @client_email.setter
    def client_email(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "client_email", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def links(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GcpLinkArgs']]]]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @links.setter
    def links(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GcpLinkArgs']]]]):
        pulumi.set(self, "links", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of GCP cloud account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[str]]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "org_id", value)

    @property
    @pulumi.getter
    def owner(self) -> Optional[pulumi.Input[str]]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @owner.setter
    def owner(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "owner", value)

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> Optional[pulumi.Input[str]]:
        """
        GCP Private key.
        """
        return pulumi.get(self, "private_key")

    @private_key.setter
    def private_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key", value)

    @property
    @pulumi.getter(name="privateKeyId")
    def private_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        GCP Private key ID.
        """
        return pulumi.get(self, "private_key_id")

    @private_key_id.setter
    def private_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_key_id", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[str]]:
        """
        GCP Project ID.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter
    def regions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @regions.setter
    def regions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "regions", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]]]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GcpTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)


class Gcp(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_email: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 private_key_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpTagArgs']]]]] = None,
                 __props__=None):
        """
        Creates a VMware vRealize Automation GCP cloud account resource.

        ## Example Usage
        ### S

        The following example shows how to create a GCP cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.Gcp("this",
            client_email="client_email",
            description="terraform test cloud account gcp",
            private_key="private_key",
            private_key_id="private_key_id",
            project_id="project_id",
            regions=[
                "us-west1",
                "us-west2",
            ],
            tags=[vra.cloudaccount.GcpTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the GCP cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/gcp:Gcp new_gcp 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] client_email: GCP Client email.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[str] name: Name of GCP cloud account.
        :param pulumi.Input[str] private_key: GCP Private key.
        :param pulumi.Input[str] private_key_id: GCP Private key ID.
        :param pulumi.Input[str] project_id: GCP Project ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpTagArgs']]]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GcpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a VMware vRealize Automation GCP cloud account resource.

        ## Example Usage
        ### S

        The following example shows how to create a GCP cloud account resource.

        ```python
        import pulumi
        import pulumiverse_vra as vra

        this = vra.cloudaccount.Gcp("this",
            client_email="client_email",
            description="terraform test cloud account gcp",
            private_key="private_key",
            private_key_id="private_key_id",
            project_id="project_id",
            regions=[
                "us-west1",
                "us-west2",
            ],
            tags=[vra.cloudaccount.GcpTagArgs(
                key="foo",
                value="bar",
            )])
        ```

        ## Import

        To import the GCP cloud account, use the ID as in the following example

        ```sh
         $ pulumi import vra:cloudaccount/gcp:Gcp new_gcp 05956583-6488-4e7d-84c9-92a7b7219a15`
        ```

        :param str resource_name: The name of the resource.
        :param GcpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GcpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 client_email: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 private_key: Optional[pulumi.Input[str]] = None,
                 private_key_id: Optional[pulumi.Input[str]] = None,
                 project_id: Optional[pulumi.Input[str]] = None,
                 regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpTagArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GcpArgs.__new__(GcpArgs)

            if client_email is None and not opts.urn:
                raise TypeError("Missing required property 'client_email'")
            __props__.__dict__["client_email"] = client_email
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if private_key is None and not opts.urn:
                raise TypeError("Missing required property 'private_key'")
            __props__.__dict__["private_key"] = private_key
            if private_key_id is None and not opts.urn:
                raise TypeError("Missing required property 'private_key_id'")
            __props__.__dict__["private_key_id"] = private_key_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            if regions is None and not opts.urn:
                raise TypeError("Missing required property 'regions'")
            __props__.__dict__["regions"] = regions
            __props__.__dict__["tags"] = tags
            __props__.__dict__["created_at"] = None
            __props__.__dict__["links"] = None
            __props__.__dict__["org_id"] = None
            __props__.__dict__["owner"] = None
            __props__.__dict__["updated_at"] = None
        super(Gcp, __self__).__init__(
            'vra:cloudaccount/gcp:Gcp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            client_email: Optional[pulumi.Input[str]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            links: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpLinkArgs']]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            org_id: Optional[pulumi.Input[str]] = None,
            owner: Optional[pulumi.Input[str]] = None,
            private_key: Optional[pulumi.Input[str]] = None,
            private_key_id: Optional[pulumi.Input[str]] = None,
            project_id: Optional[pulumi.Input[str]] = None,
            regions: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpTagArgs']]]]] = None,
            updated_at: Optional[pulumi.Input[str]] = None) -> 'Gcp':
        """
        Get an existing Gcp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] client_email: GCP Client email.
        :param pulumi.Input[str] created_at: Date when entity was created. Date and time format is ISO 8601 and UTC.
        :param pulumi.Input[str] description: Human-friendly description.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpLinkArgs']]]] links: HATEOAS of entity.
        :param pulumi.Input[str] name: Name of GCP cloud account.
        :param pulumi.Input[str] org_id: ID of organization that entity belongs to.
        :param pulumi.Input[str] owner: Email of entity owner.
        :param pulumi.Input[str] private_key: GCP Private key.
        :param pulumi.Input[str] private_key_id: GCP Private key ID.
        :param pulumi.Input[str] project_id: GCP Project ID.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] regions: Set of region names enabled for the cloud account.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['GcpTagArgs']]]] tags: Set of tag keys and values to apply to the cloud account.  
               Example:[ { "key" : "vmware", "value": "provider" } ]
        :param pulumi.Input[str] updated_at: Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GcpState.__new__(_GcpState)

        __props__.__dict__["client_email"] = client_email
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["links"] = links
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["owner"] = owner
        __props__.__dict__["private_key"] = private_key
        __props__.__dict__["private_key_id"] = private_key_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["regions"] = regions
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_at"] = updated_at
        return Gcp(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clientEmail")
    def client_email(self) -> pulumi.Output[str]:
        """
        GCP Client email.
        """
        return pulumi.get(self, "client_email")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        Date when entity was created. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Human-friendly description.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def links(self) -> pulumi.Output[Sequence['outputs.GcpLink']]:
        """
        HATEOAS of entity.
        """
        return pulumi.get(self, "links")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Name of GCP cloud account.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[str]:
        """
        ID of organization that entity belongs to.
        """
        return pulumi.get(self, "org_id")

    @property
    @pulumi.getter
    def owner(self) -> pulumi.Output[str]:
        """
        Email of entity owner.
        """
        return pulumi.get(self, "owner")

    @property
    @pulumi.getter(name="privateKey")
    def private_key(self) -> pulumi.Output[str]:
        """
        GCP Private key.
        """
        return pulumi.get(self, "private_key")

    @property
    @pulumi.getter(name="privateKeyId")
    def private_key_id(self) -> pulumi.Output[str]:
        """
        GCP Private key ID.
        """
        return pulumi.get(self, "private_key_id")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[str]:
        """
        GCP Project ID.
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def regions(self) -> pulumi.Output[Sequence[str]]:
        """
        Set of region names enabled for the cloud account.
        """
        return pulumi.get(self, "regions")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.GcpTag']]:
        """
        Set of tag keys and values to apply to the cloud account.  
        Example:[ { "key" : "vmware", "value": "provider" } ]
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        Date when entity was last updated. Date and time format is ISO 8601 and UTC.
        """
        return pulumi.get(self, "updated_at")

